cross2_to_grcm39: Convert a cross2 object to use mouse build GRCm39
Description
Convert a cross2 object (with genotypes from one of the MUGA
arrays) to use mouse build GRCm39 and the revised Cox map
positions, revising marker order and omitting markers that are not
found.
The input cross object with markers subset to those in build GRCm39
and with pmap and gmap replaced with the GRCm39 physical map and
revised Cox genetic map, respectively.
Arguments
cross
Object of class "cross2", as produced by
qtl2::read_cross2(). Must have markers from just one of the MUGA arrays.
array
Character string indicating which of the MUGA arrays
was used ("gm" for GigaMUGA, "mm" for MegaMUGA, "mini" for
MiniMUGA, or "muga" for the original MUGA), or "guess" (the
default) to pick the array with the most matching marker names.